@@ -1,14 +1,12 @@
 package Set::Tiny;
-
-use warnings;
 use strict;
+use warnings;
+
+our $VERSION = '0.06';
+
 use Exporter 'import';
 our @EXPORT_OK = qw(set);
 
-our $VERSION = '0.05'; # VERSION
-
-# ABSTRACT: Simple sets of strings
-
 sub new {
     my $class = shift;
     my %self;
@@ -16,7 +14,7 @@ sub new {
     return bless \%self, $class;
 }
 
-sub set {
+sub set { ## no critic (NamingConventions::ProhibitAmbiguousNames)
     if ( ref( $_[0] ) eq 'Set::Tiny' ) {
         return $_[0]->clone();
     }
@@ -38,8 +36,8 @@ sub elements { keys %{ $_[0] } }
 
 sub contains {
     my $self = shift;
-    exists $self->{$_} or return for @_;
-    return 1;
+    exists $self->{$_} or return !!0 for @_;
+    return !!1;
 }
 
 sub clone {
@@ -88,8 +86,8 @@ sub is_disjoint { !$_[0]->intersection( $_[1] )->size }
 
 sub is_properly_intersecting {
     !$_[0]->is_disjoint( $_[1] )
-      && $_[0]->difference( $_[1] )->size
-      && $_[1]->difference( $_[0] )->size;
+        && $_[0]->difference( $_[1] )->size
+        && $_[1]->difference( $_[0] )->size;
 }
 
 sub difference { $_[0]->clone->remove( keys %{ $_[1] } ) }
@@ -107,7 +105,7 @@ sub intersection {
 sub intersection2 {
     my $class = ref $_[0];
     my ( $a, $b ) =
-      $_[0]->size > $_[1]->size ? ( $_[0], $_[1] ) : ( $_[1], $_[0] );
+        $_[0]->size > $_[1]->size ? ( $_[0], $_[1] ) : ( $_[1], $_[0] );
     return $class->new( grep { exists( $a->{$_} ) } keys %{$b} );
 }
 
@@ -131,14 +129,12 @@ __END__
 
 =encoding UTF-8
 
+=for :stopwords Stanis Trendelenburg superset
+
 =head1 NAME
 
 Set::Tiny - Simple sets of strings
 
-=head1 VERSION
-
-version 0.05
-
 =head1 SYNOPSIS
 
     use Set::Tiny;
@@ -356,6 +352,47 @@ L<Set::Scalar>
 
 =back
 
+=head1 BUGS
+
+Please report any bugs or feature requests on the bugtracker website
+L<https://github.com/haarg/Set-Tiny/issues>
+
+When submitting a bug or request, please include a test-file or a
+patch to an existing test-file that illustrates the bug or desired
+feature.
+
+=head1 CONTRIBUTORS
+
+=for stopwords Alberto Manuel Brandão Simões Alceu Rodrigues de Freitas Junior brian greenfield Graham Knop Ricky Morse Stanis Trendelenburg
+
+=over 4
+
+=item *
+
+Alberto Manuel Brandão Simões <ambs@cpan.org>
+
+=item *
+
+Alceu Rodrigues de Freitas Junior <glasswalk3r@yahoo.com.br>
+
+=item *
+
+brian greenfield <briang@cpan.org>
+
+=item *
+
+Graham Knop <haarg@haarg.org>
+
+=item *
+
+Ricky Morse <remorse@mgh.harvard.edu>
+
+=item *
+
+Stanis Trendelenburg <stanis.trendelenburg@gmail.com>
+
+=back
+
 =head1 AUTHOR
 
 Stanis Trendelenburg <trendels@cpan.org>
